pub struct SerializableFunctionDebugInfo {
pub function_file_path: SourceFileFullPath,
pub function_code_span: SourceCodeSpan,
pub sierra_to_cairo_variable: HashMap<SierraVarId, (String, SourceCodeSpan)>,
pub parameters: HashMap<SierraVarId, CairoVariableDefinition>,
}Expand description
The serializable debug info of a sierra function.
Fields
function_file_path: SourceFileFullPathPath to the user file the function comes from.
function_code_span: SourceCodeSpanSpan of the function in the user file it comes from.
sierra_to_cairo_variable: HashMap<SierraVarId, (String, SourceCodeSpan)>Mapping from a sierra variable to a cairo variable (its name and definition span). The sierra variable value corresponds to the cairo variable value at some point during execution of the function code.
parameters: HashMap<SierraVarId, CairoVariableDefinition>Additional mapping for parameters specifically, as these may later be overridden.